==> visualpython-0.4.0.tar.gz: visualpython-0.4.0/visualpython/src/pandas/fileNavigation/index.js <==
define([
    'require'
    , 'jquery'
    , 'nbextensions/visualpython/src/common/vpCommon'
    , 'nbextensions/visualpython/src/common/constant'
    , 'nbextensions/visualpython/src/common/StringBuilder'
    , 'nbextensions/visualpython/src/common/vpFuncJS'
    //
    , './state'
    , './renderer' // 렌더링 수정
    , 'nbextensions/visualpython/src/component/fileNavigation/constData'
    , 'nbextensions/visualpython/src/component/fileNavigation/executor'
], function ( requirejs, $, vpCommon, vpConst, sb, vpFuncJS, FileNavigationState, FileNavigationRenderer, constData,
              executor) {

    const { executeKernelFromDirBody } = executor;
    const { NAVIGATION_DIRECTION_TYPE } = constData;

    var sbCode = new sb.StringBuilder();
    // 옵션 속성
    const funcOptProp = {
        stepCount : 1
        , funcName : "fileNavigation"
        , funcID : "JY900"  // TODO: ID 규칙 생성 필요
    }
    var vpFuncJS = new vpFuncJS.VpFuncJS(funcOptProp);

    var fileNavigationState;
    var fileNavigationRenderer  

    // 시작
    var vp_init = function(importPackageThis, type) {

        fileNavigationState = new FileNavigationState();
        fileNavigationState.setFileOptionData(importPackageThis.state);
        fileNavigationState.setImportPackageThis(importPackageThis);
        fileNavigationState.setFileNavigationtype(type);
        fileNavigationRenderer = new FileNavigationRenderer(fileNavigationState, vpFuncJS, importPackageThis.fileResultState);

        vpFuncJS.kernelExecuteV2(`%pwd`,(currentDirStr) => {
            var slicedCurrentDirStr = currentDirStr.slice(1, currentDirStr.length -1);
                slicedCurrentDirStr = slicedCurrentDirStr.replace(/\\/g, `/`);
      
            //** slicedCurrentDirStr = slicedCurrentDirStr.replaceAll("//","/"); 이 기능을 아래 logic으로 대체 */
            var cursor = 0;
            while (slicedCurrentDirStr[cursor] !== undefined ) {
                if(slicedCurrentDirStr[cursor] === "/" && slicedCurrentDirStr[cursor + 1] === "/") {
                    slicedCurrentDirStr = slicedCurrentDirStr.slice(0,cursor) + slicedCurrentDirStr.slice(cursor + 1,slicedCurrentDirStr.length);
                }
                cursor++;
            }
             
            var splitedDirStrArr = slicedCurrentDirStr.split('/');
            /** 만약 현재 전체 path가 C:/Users/L.E.E/Desktop/Bit Python이라면,
             *  BaseFolderStr는  Bit Python
             *  BaseDirStr는  C:/Users/L.E.E/Desktop/Bit Python
             *  RelativePathStr는 Bit Python
             *  RelativePathStr는 파일 네비게이션 이동하면서 계속 달라진다
             */
            var rootFolderName = splitedDirStrArr[splitedDirStrArr.length - 1];
            var notebookPath = Jupyter.notebook.notebook_path;

            fileNavigationState.setBaseFolder(rootFolderName);
            fileNavigationState.setRelativeDir(rootFolderName);
            fileNavigationState.setBaseDir(slicedCurrentDirStr);

            var baseDirStr = fileNavigationState.getBaseDir();

            /** jupyter.notebook.notebook_path 의 값을 토대로
             *  notebookFolder 와 notebookPathStr을 생성
             *  만약 현재 전체 path가 C:/Users/L.E.E/Desktop/Bit Python이라면,
             *  Jupyter.notebook.notebook_path 는 Desktop/Bit Python
             *  notebookFolder는 Desktop
             *  notebookPathStr는 Desktop/Bit Python
             *  사용자가 위로 올라갈 수 있는 최상위 부모 폴더는 L.E.E
             */
            if (notebookPath.indexOf("/") !== -1) {
                var index = 0;
                while ( notebookPath[index] !== "/" ) {
                    if ( notebookPath[index] === undefined ) {
                        break;
                    }
                    index++;
                }
            
                var notebookFolder = notebookPath.substring(0, index);
                var index2 = baseDirStr.indexOf(notebookFolder);
                while (baseDirStr[index2] !== "/") {
                    if ( baseDirStr[index2] === undefined ) {
                        break;
                    }
                    index2++;
                }

                var notebookFullPathStr = baseDirStr.substring(0, index2);
                var index3 = notebookFullPathStr.indexOf(notebookFolder);
                var notebookPathStr = baseDirStr.substring(0, index3 - 1);

                fileNavigationState.setNotebookFolder(notebookFolder);
                fileNavigationState.setNotebookDir(notebookPathStr);
            } else {
  
                fileNavigationState.setNotebookFolder(rootFolderName);
                fileNavigationState.setNotebookDir(slicedCurrentDirStr);
            }

        });
        fileNavigationRenderer.initRender();
    }


    var vp_bindEventFunctions = function() {
        // 파일네비게이션을 닫았을때 실행되는 click 함수
        $('.directoryComponent-closedBtn').click(() => {
            fileNavigationState.resetStack();
            $('#vp_fileNavigation').addClass("hide");
            $('#vp_fileNavigation').removeClass("show");
            $('#vp_fileNavigation').remove();
            
            // 파일 네비게이션에서 생성된 script 파일 삭제
            vpCommon.removeHeadScript("fileNavigation");
            vpCommon.removeHeadScript("loadingBar");
            vpCommon.removeHeadScript("successMessage");
            vpCommon.removeHeadScript("yesOrNoModal");
        });
    
        // 상위 디렉토리 클릭시 실행되는 함수
        $('.directoryComponent-btn-up').click(() => {
            /** 나의 현재 path가 Jupyternotebook path와 동일할 경우  */
            if ( fileNavigationState.getCurrentDir() === fileNavigationState.getNotebookDir() ) {
                vpCommon.renderAlertModal('Cannot search higher than jupyter directory');
                return;
            }

            var currentDirStr = fileNavigationState.getCurrentDir();
            var index = currentDirStr.length;
            var upDirStr = ``;

            /** 한 depth 상위의 path를 만든다 */
            while (index-- > 0) {
                if ( currentDirStr[index] === "/" ) {
                    upDirStr = currentDirStr.substring(0, index);
                    break;
                }
            }
            
            /** 그리고 만든 상위의 path를 파이썬 커널로 던진다 */
            var dirObj = {
                direction: NAVIGATION_DIRECTION_TYPE.TO,
                destDir: upDirStr
            }  
            executeKernelFromDirBody(dirObj, fileNavigationRenderer);
        });
    
        // 이전 디렉토리 검색 클릭시 실행되는 함수
        $('.directoryComponent-btn-prev').click(() => {
            if (fileNavigationState.getDirHistoryStack().length === 0) {
                vpCommon.renderAlertModal('No previous directory');
                return;
            }
            // 이전 디렉토리 history stack 목록을 뒤져서,
            // 가장 최근에 다녀간 이전 디렉토리로 검색
            var popedData = fileNavigationState.popDirHistoryStackAndGetPopedData();
            var dirObj = {
                direction: NAVIGATION_DIRECTION_TYPE.PREV,
                destDir: popedData.prev
            }
            executeKernelFromDirBody(dirObj, fileNavigationRenderer);         
        });
    }
   
    return {
        vp_init
        , vp_bindEventFunctions
    }
});

==> visualpython-0.6.0.tar.gz: visualpython-0.6.0/visualpython/src/pandas/fileNavigation/index.js <==
define([
    'require'
    , 'jquery'
    , 'nbextensions/visualpython/src/common/vpCommon'
    , 'nbextensions/visualpython/src/common/constant'
    , 'nbextensions/visualpython/src/common/StringBuilder'
    , 'nbextensions/visualpython/src/common/vpFuncJS'
    //
    , './state'
    , './renderer' // 렌더링 수정
    , 'nbextensions/visualpython/src/component/fileNavigation/constData'
    , 'nbextensions/visualpython/src/component/fileNavigation/executor'
], function ( requirejs, $, vpCommon, vpConst, sb, vpFuncJS, FileNavigationState, FileNavigationRenderer, constData,
              executor) {

    const { executeKernelFromDirBody } = executor;
    const { NAVIGATION_DIRECTION_TYPE } = constData;

    var sbCode = new sb.StringBuilder();
    // 옵션 속성
    const funcOptProp = {
        stepCount : 1
        , funcName : "fileNavigation"
        , funcID : "JY900"  // TODO: ID 규칙 생성 필요
    }
    var vpFuncJS = new vpFuncJS.VpFuncJS(funcOptProp);

    var fileNavigationState;
    var fileNavigationRenderer  

    // 시작
    var vp_init = function(importPackageThis, type) {

        fileNavigationState = new FileNavigationState();
        fileNavigationState.setFileOptionData(importPackageThis.state);
        fileNavigationState.setImportPackageThis(importPackageThis);
        fileNavigationState.setFileNavigationtype(type);
        fileNavigationRenderer = new FileNavigationRenderer(fileNavigationState, vpFuncJS, importPackageThis.fileResultState);

        vpFuncJS.kernelExecuteV2(`%pwd`,(currentDirStr) => {
            var slicedCurrentDirStr = currentDirStr.slice(1, currentDirStr.length -1);
                slicedCurrentDirStr = slicedCurrentDirStr.replace(/\\/g, `/`);
      
            //** slicedCurrentDirStr = slicedCurrentDirStr.replaceAll("//","/"); 이 기능을 아래 logic으로 대체 */
            var cursor = 0;
            while (slicedCurrentDirStr[cursor] !== undefined ) {
                if(slicedCurrentDirStr[cursor] === "/" && slicedCurrentDirStr[cursor + 1] === "/") {
                    slicedCurrentDirStr = slicedCurrentDirStr.slice(0,cursor) + slicedCurrentDirStr.slice(cursor + 1,slicedCurrentDirStr.length);
                }
                cursor++;
            }
            fileNavigationState.pushDirHistoryStack(slicedCurrentDirStr);
            // console.log('slicedCurrentDirStr',slicedCurrentDirStr);
            var splitedDirStrArr = slicedCurrentDirStr.split('/');
            /** 만약 현재 전체 path가 C:/Users/L.E.E/Desktop/Bit Python이라면,
             *  BaseFolderStr는  Bit Python
             *  BaseDirStr는  C:/Users/L.E.E/Desktop/Bit Python
             *  RelativePathStr는 Bit Python
             *  RelativePathStr는 파일 네비게이션 이동하면서 계속 달라진다
             */
            var rootFolderName = splitedDirStrArr[splitedDirStrArr.length - 1];
            var notebookPath = Jupyter.notebook.notebook_path;

            fileNavigationState.setBaseFolder(rootFolderName);
            fileNavigationState.setRelativeDir(rootFolderName);
            fileNavigationState.setBaseDir(slicedCurrentDirStr);

            var baseDirStr = fileNavigationState.getBaseDir();

            /** jupyter.notebook.notebook_path 의 값을 토대로
             *  notebookFolder 와 notebookPathStr을 생성
             *  만약 현재 전체 path가 C:/Users/L.E.E/Desktop/Bit Python이라면,
             *  Jupyter.notebook.notebook_path 는 Desktop/Bit Python
             *  notebookFolder는 Desktop
             *  notebookPathStr는 Desktop/Bit Python
             *  사용자가 위로 올라갈 수 있는 최상위 부모 폴더는 L.E.E
             */
            if (notebookPath.indexOf("/") !== -1) {
                var index = 0;
                while ( notebookPath[index] !== "/" ) {
                    if ( notebookPath[index] === undefined ) {
                        break;
                    }
                    index++;
                }
            
                var notebookFolder = notebookPath.substring(0, index);
                var index2 = baseDirStr.indexOf(notebookFolder);
                while (baseDirStr[index2] !== "/") {
                    if ( baseDirStr[index2] === undefined ) {
                        break;
                    }
                    index2++;
                }

                var notebookFullPathStr = baseDirStr.substring(0, index2);
                var index3 = notebookFullPathStr.indexOf(notebookFolder);
                var notebookPathStr = baseDirStr.substring(0, index3 - 1);

                fileNavigationState.setNotebookFolder(notebookFolder);
                fileNavigationState.setNotebookDir(notebookPathStr);
            } else {
  
                fileNavigationState.setNotebookFolder(rootFolderName);
                fileNavigationState.setNotebookDir(slicedCurrentDirStr);
            }

        });
        fileNavigationRenderer.initRender();
    }


    var vp_bindEventFunctions = function() {
        // 파일네비게이션을 닫았을때 실행되는 click 함수
        $('.directoryComponent-closedBtn').click(() => {
            fileNavigationState.resetStack();
            $('#vp_fileNavigation').addClass("hide");
            $('#vp_fileNavigation').removeClass("show");
            $('#vp_fileNavigation').remove();
            
            // 파일 네비게이션에서 생성된 script 파일 삭제
            vpCommon.removeHeadScript("fileNavigation");
            vpCommon.removeHeadScript("loadingBar");
            vpCommon.removeHeadScript("successMessage");
            vpCommon.removeHeadScript("yesOrNoModal");
        });
    
        // 상위 디렉토리 클릭시 실행되는 함수
        $('.directoryComponent-btn-up').click(() => {

            if (fileNavigationState.stackCursor + 1 == fileNavigationState.getDirHistoryStack().length) {
                vpCommon.renderAlertModal('No next directory');
                return;
            }

            fileNavigationState.stackCursor++;

            var nextData = fileNavigationState.getNextDirHistoryStack();
            /** 그리고 만든 상위의 path를 파이썬 커널로 던진다 */
            var dirObj = {
                direction: NAVIGATION_DIRECTION_TYPE.PREV,
                destDir: nextData
            }  
            executeKernelFromDirBody(dirObj, fileNavigationRenderer);
        });
    
        // 이전 디렉토리 검색 클릭시 실행되는 함수
        $('.directoryComponent-btn-prev').click(() => {

            if (fileNavigationState.stackCursor <= 0) {
                vpCommon.renderAlertModal('No previous directory');
                return;
            }
            fileNavigationState.stackCursor--;

            var popedData = fileNavigationState.popDirHistoryStackAndGetPopedData();
            var dirObj = {
                direction: NAVIGATION_DIRECTION_TYPE.PREV,
                destDir: popedData
            }
            executeKernelFromDirBody(dirObj, fileNavigationRenderer);         
        });
    }
   
    return {
        vp_init
        , vp_bindEventFunctions
    }
});
